import { expect } from 'chai'
import data from './data/data'
import NavBar from './NavBar'

testComponent(
  () => NavBar,
  { props: [{ name: 'data', value: data }] },
  ({ testTagAndClass, render, sinon }) => {
    testTagAndClass('div', 'nav-container')

    it('should call toggle when clicked', () => {
      const toggleStub = sinon.stub()

      const wrapper = render({ toggle: toggleStub })
      wrapper.find('.burger').simulate('click')
      expect(toggleStub).to.have.been.calledOnce
    })

    it('should set hamburger to active when open prop is true', () => {
      const wrapper = render({ open: true })
      expect(wrapper.find('.burger').attr('class')).to.contain('active')
    })

    it('should not render <a> tag with title if not present', () => {
      const wrapper = render()
      expect(wrapper.find('.site-tite').exists()).to.equal(false)
    })

    it('should render <a> tag with title prop if present', () => {
      const wrapper = render({ title: 'test' })
      expect(wrapper.find('.site-title').exists()).to.equal(true)
    })

    it('should render title with link if title_url prop present', () => {
      const wrapper = render({
        title_url: 'http://www.google.com',
        title: 'foo'
      })
      expect(wrapper.find('.site-title').attr('href')).to.equal(
        'http://www.google.com'
      )
    })

    it('should render title with link to hashicorp.com if no title_url', () => {
      const wrapper = render({ title: 'foo' })
      expect(wrapper.find('.site-title').attr('href')).to.equal(
        'https://www.hashicorp.com'
      )
    })

    it('should link logo to home_url prop if present', () => {
      const wrapper = render({ home_url: 'http://www.theoatmeal.com' })
      expect(
        wrapper
          .find('.logo-group')
          .find('a')
          .attr('href')
      ).to.equal('http://www.theoatmeal.com')
    })

    it('should link logo to hashicorp.com if home_url prop not present', () => {
      const wrapper = render()
      expect(
        wrapper
          .find('.logo-group')
          .find('a')
          .attr('href')
      ).to.equal('https://www.hashicorp.com')
    })
  }
)
