import { h } from 'preact'
import NewsletterSignup from '@hashicorp/hashi-newsletter-signup-form'
import NavSection from './NavSection'
import NavBar from './NavBar'
import Button from '@hashicorp/hashi-button'

export default function NavMenu({
  data,
  enter,
  exit,
  toggle,
  open,
  title,
  title_url,
  home_url
}) {
  return (
    <div class={`menu-container ${open ? 'open' : ''}`} role="menu">
      <div class="g-container">
        <NavBar
          data={data}
          toggle={toggle}
          open={open}
          title={title}
          home_url={home_url}
          title_url={title_url}
        />
        <ul class="menu">
          <ul class="left">
            <NavSection name="Products" enter={enter} exit={exit}>
              {data.products_links.map(item => (
                <li class="product" key={item.name}>
                  <a
                    class={`${item.slug ? item.slug.toLowerCase() : ''}`}
                    href={`https://www.hashicorp.com/products/${item.slug}`}
                    data-ga-meganav={`Products | ${item.slug}`}
                  >
                    <img
                      class="product-icon color"
                      src={item.color_logo.url}
                      alt={item.color_logo.alt}
                    />
                    <img
                      class="product-icon light"
                      src={item.logo.url}
                      alt={item.logo.alt}
                    />
                    <span class="product-name">{`${item.slug
                      .charAt(0)
                      .toUpperCase()}${item.slug
                      .substr(1)
                      .toLowerCase()}`}</span>
                  </a>
                </li>
              ))}
              <li class="callout">
                <h4>{data.callout.headline}</h4>
                <p>{data.callout.body}</p>
                <Button
                  url={data.callout.button.url}
                  title={data.callout.button.title}
                  theme="dark-outline"
                />
              </li>
            </NavSection>
          </ul>
          <ul class="right">
            <NavSection name="Resources" enter={enter} exit={exit}>
              {data.resources_links.map(item => (
                <li key={item.title}>
                  <a
                    href={item.url}
                    data-ga-meganav={`Resources | ${item.title}`}
                  >
                    {item.title}
                  </a>
                </li>
              ))}
            </NavSection>
            <NavSection name="Company" enter={enter} exit={exit}>
              {data.company_links.map(item => (
                <li key={item.title}>
                  <a
                    href={item.url}
                    data-ga-meganav={`Company | ${item.title}`}
                  >
                    {item.title}
                  </a>
                </li>
              ))}
            </NavSection>
            <NavSection name="Partners" enter={enter} exit={exit}>
              {data.partners_links.map(item => (
                <li key={item.title}>
                  <a
                    href={item.url}
                    data-ga-meganav={`Partners | ${item.title}`}
                  >
                    {item.title}
                  </a>
                </li>
              ))}
            </NavSection>
            <NavSection name="Docs" enter={enter} exit={exit}>
              {data.docs_links.map(item => (
                <li key={item.title}>
                  <a href={item.url} data-ga-meganav={`Docs | ${item.title}`}>
                    {item.title}
                  </a>
                </li>
              ))}
            </NavSection>
            {data.footer_links.map(link => (
              <li class="single-link" key={link.title}>
                <a
                  href={link.url}
                  data-ga-meganav={`Nav footer | ${link.title}`}
                >
                  {link.title}
                </a>
              </li>
            ))}
          </ul>
        </ul>
        <div class="menu-footer">
          <div class="newsletter">
            <NewsletterSignup
              placeholder="Email address"
              button_text="Sign-up for updates"
            />
          </div>
          <div class="links">
            <ul class="footer-links">
              {data.footer_links.map(link => (
                <li key={link.title}>
                  <a
                    href={link.url}
                    data-ga-meganav={`Nav footer | ${link.title}`}
                  >
                    {link.title}
                  </a>
                </li>
              ))}
            </ul>
            <ul class="social-links">
              {data.social_links.map(link => (
                <li key={link.url}>
                  <a
                    href={link.url}
                    target="_blank"
                    rel="noopener noreferrer"
                    data-ga-meganav={`Social | ${link.network.name}`}
                  >
                    <img
                      src={link.network.icon_dark.url}
                      alt={link.network.icon_dark.alt}
                    />
                  </a>
                </li>
              ))}
            </ul>
          </div>
        </div>
      </div>
    </div>
  )
}
