import { expect } from 'chai'
import data from './data/data'
import NavMenu from './NavMenu'

testComponent(
  () => NavMenu,
  { props: [{ name: 'data', value: data }] },
  ({ testTagAndClass, render }) => {
    testTagAndClass('div', 'menu-container')

    it('should have class of open when prop open = true', () => {
      const wrapper = render({ open: true })
      expect(wrapper.find('.menu-container').attr('class')).contains('open')
    })

    it('should render products data with logos', () => {
      const wrapper = render()

      expect(wrapper.find('.product')).to.be.lengthOf(
        data.products_links.length
      )

      // Spot checking
      expect(
        wrapper
          .find('.product')
          .first()
          .find('img')
          .first()
          .attr('src')
      ).to.equal(data.products_links[0].color_logo.url)

      expect(
        wrapper
          .find('.product')
          .first()
          .find('a')
          .attr('class')
      ).to.contain(data.products_links[0].name.toLowerCase())
    })

    it('should render a callout properly', () => {
      const wrapper = render()

      expect(
        wrapper
          .find('.callout')
          .find('h4')
          .text()
      ).to.equal(data.callout.headline)
      expect(
        wrapper
          .find('.callout')
          .find('p')
          .text()
      ).to.equal(data.callout.body)
    })
  }
)
