import { h } from 'preact'
import { expect } from 'chai'
import NavSection from './NavSection'
import propsSpec from './props.js'

testComponent(
  () => NavSection,
  { props: propsSpec },
  ({ testTagAndClass, render, sinon }) => {
    testTagAndClass('li', 'nav-block')

    it('should have a name class', () => {
      const wrapper = render({ name: 'Monkey' })
      expect(wrapper.find('.nav-block').attr('class')).to.contain('monkey')
      expect(wrapper.find('.submenu').attr('class')).to.contain('monkey')
    })

    it('should call enter on click', () => {
      const enterStub = sinon.stub()

      const wrapper = render({ enter: enterStub })
      wrapper
        .find('a')
        .first()
        .simulate('click')
      expect(enterStub).to.have.been.calledOnce
    })

    it('should call exit on click', () => {
      const exitStub = sinon.stub()

      const wrapper = render({ exit: exitStub })
      wrapper.find('.close').simulate('click')
      expect(exitStub).to.have.been.calledOnce
    })

    it('should render children', () => {
      const wrapper = render({ children: <div class="neat">stuff</div> })

      expect(wrapper.find('.neat').text()).to.equal('stuff')
    })
  }
)
