'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var preact = require('preact');
var reshapePreactComponents = require('reshape-preact-components');
var NewsletterSignup = _interopDefault(require('@hashicorp/hashi-newsletter-signup-form'));
var Button = _interopDefault(require('@hashicorp/hashi-button'));

function NavSection(_ref) {
  var name = _ref.name,
      enter = _ref.enter,
      exit = _ref.exit,
      children = _ref.children;

  return preact.h(
    'li',
    {
      'class': 'nav-block ' + (name ? name.toLowerCase().replace(/\s/, '-') : '')
    },
    preact.h(
      'h6',
      { 'class': 'submenu-header' },
      name
    ),
    preact.h(
      'a',
      { onClick: enter },
      name
    ),
    preact.h(
      'ul',
      {
        'class': 'submenu ' + (name ? name.toLowerCase().replace(/\s/, '-') : '')
      },
      preact.h(
        'li',
        { 'class': 'close', onClick: exit },
        preact.h(
          'span',
          null,
          '\u2039'
        ),
        ' Back'
      ),
      preact.h(
        'li',
        { 'class': 'name' },
        name
      ),
      children
    )
  );
}

function NavBar(_ref) {
  var open = _ref.open,
      toggle = _ref.toggle,
      data = _ref.data,
      title = _ref.title,
      title_url = _ref.title_url,
      home_url = _ref.home_url;

  var homeUrl = home_url ? home_url : 'https://www.hashicorp.com';
  return preact.h(
    'div',
    { 'class': 'nav-container' },
    preact.h(
      'div',
      { 'class': 'logo-group' },
      preact.h(
        'a',
        { href: homeUrl },
        preact.h('img', {
          'class': 'logo',
          src: data.primary_logo.url,
          alt: data.primary_logo.alt
        })
      ),
      title && preact.h(
        'a',
        { 'class': 'site-title', href: title_url || homeUrl },
        title
      )
    ),
    preact.h(
      'button',
      {
        'class': 'burger' + (open ? ' active' : ''),
        onClick: toggle,
        'aria-haspopup': 'true',
        'aria-expanded': open ? 'true' : 'false'
      },
      preact.h('span', null),
      preact.h('span', null),
      preact.h('span', null),
      preact.h('span', null)
    )
  );
}

function NavMenu(_ref) {
  var data = _ref.data,
      enter = _ref.enter,
      exit = _ref.exit,
      toggle = _ref.toggle,
      open = _ref.open,
      title = _ref.title,
      title_url = _ref.title_url,
      home_url = _ref.home_url;

  return preact.h(
    'div',
    { 'class': 'menu-container ' + (open ? 'open' : ''), role: 'menu' },
    preact.h(
      'div',
      { 'class': 'g-container' },
      preact.h(NavBar, {
        data: data,
        toggle: toggle,
        open: open,
        title: title,
        home_url: home_url,
        title_url: title_url
      }),
      preact.h(
        'ul',
        { 'class': 'menu' },
        preact.h(
          'ul',
          { 'class': 'left' },
          preact.h(
            NavSection,
            { name: 'Products', enter: enter, exit: exit },
            data.products_links.map(function (item) {
              return preact.h(
                'li',
                { 'class': 'product', key: item.name },
                preact.h(
                  'a',
                  {
                    'class': '' + (item.slug ? item.slug.toLowerCase() : ''),
                    href: 'https://www.hashicorp.com/products/' + item.slug,
                    'data-ga-meganav': 'Products | ' + item.slug
                  },
                  preact.h('img', {
                    'class': 'product-icon color',
                    src: item.color_logo.url,
                    alt: item.color_logo.alt
                  }),
                  preact.h('img', {
                    'class': 'product-icon light',
                    src: item.logo.url,
                    alt: item.logo.alt
                  }),
                  preact.h(
                    'span',
                    { 'class': 'product-name' },
                    '' + item.slug.charAt(0).toUpperCase() + item.slug.substr(1).toLowerCase()
                  )
                )
              );
            }),
            preact.h(
              'li',
              { 'class': 'callout' },
              preact.h(
                'h4',
                null,
                data.callout.headline
              ),
              preact.h(
                'p',
                null,
                data.callout.body
              ),
              preact.h(Button, {
                url: data.callout.button.url,
                title: data.callout.button.title,
                theme: 'dark-outline'
              })
            )
          )
        ),
        preact.h(
          'ul',
          { 'class': 'right' },
          preact.h(
            NavSection,
            { name: 'Resources', enter: enter, exit: exit },
            data.resources_links.map(function (item) {
              return preact.h(
                'li',
                { key: item.title },
                preact.h(
                  'a',
                  {
                    href: item.url,
                    'data-ga-meganav': 'Resources | ' + item.title
                  },
                  item.title
                )
              );
            })
          ),
          preact.h(
            NavSection,
            { name: 'Company', enter: enter, exit: exit },
            data.company_links.map(function (item) {
              return preact.h(
                'li',
                { key: item.title },
                preact.h(
                  'a',
                  {
                    href: item.url,
                    'data-ga-meganav': 'Company | ' + item.title
                  },
                  item.title
                )
              );
            })
          ),
          preact.h(
            NavSection,
            { name: 'Partners', enter: enter, exit: exit },
            data.partners_links.map(function (item) {
              return preact.h(
                'li',
                { key: item.title },
                preact.h(
                  'a',
                  {
                    href: item.url,
                    'data-ga-meganav': 'Partners | ' + item.title
                  },
                  item.title
                )
              );
            })
          ),
          preact.h(
            NavSection,
            { name: 'Docs', enter: enter, exit: exit },
            data.docs_links.map(function (item) {
              return preact.h(
                'li',
                { key: item.title },
                preact.h(
                  'a',
                  { href: item.url, 'data-ga-meganav': 'Docs | ' + item.title },
                  item.title
                )
              );
            })
          ),
          data.footer_links.map(function (link) {
            return preact.h(
              'li',
              { 'class': 'single-link', key: link.title },
              preact.h(
                'a',
                {
                  href: link.url,
                  'data-ga-meganav': 'Nav footer | ' + link.title
                },
                link.title
              )
            );
          })
        )
      ),
      preact.h(
        'div',
        { 'class': 'menu-footer' },
        preact.h(
          'div',
          { 'class': 'newsletter' },
          preact.h(NewsletterSignup, {
            placeholder: 'Email address',
            button_text: 'Sign-up for updates'
          })
        ),
        preact.h(
          'div',
          { 'class': 'links' },
          preact.h(
            'ul',
            { 'class': 'footer-links' },
            data.footer_links.map(function (link) {
              return preact.h(
                'li',
                { key: link.title },
                preact.h(
                  'a',
                  {
                    href: link.url,
                    'data-ga-meganav': 'Nav footer | ' + link.title
                  },
                  link.title
                )
              );
            })
          ),
          preact.h(
            'ul',
            { 'class': 'social-links' },
            data.social_links.map(function (link) {
              return preact.h(
                'li',
                { key: link.url },
                preact.h(
                  'a',
                  {
                    href: link.url,
                    target: '_blank',
                    rel: 'noopener noreferrer',
                    'data-ga-meganav': 'Social | ' + link.network.name
                  },
                  preact.h('img', {
                    src: link.network.icon_dark.url,
                    alt: link.network.icon_dark.alt
                  })
                )
              );
            })
          )
        )
      )
    )
  );
}

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var MegaNav = function (_Component) {
  _inherits(MegaNav, _Component);

  function MegaNav(props) {
    _classCallCheck(this, MegaNav);

    var _this = _possibleConstructorReturn(this, (MegaNav.__proto__ || Object.getPrototypeOf(MegaNav)).call(this, props));

    _this.state = { menuOpen: false };
    _this.toggleMenu = _this.toggleMenu.bind(_this);
    _this.handleEscKey = _this.handleEscKey.bind(_this);
    _this.enterMobileSubnav = _this.enterMobileSubnav.bind(_this);
    _this.exitMobileSubnav = _this.exitMobileSubnav.bind(_this);
    return _this;
  }

  _createClass(MegaNav, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      window.addEventListener('keyup', this.handleEscKey);
    }
  }, {
    key: 'handleEscKey',
    value: function handleEscKey(e) {
      if (e.keyCode === 27 && this.state.menuOpen) {
        this.toggleMenu();
      }
    }
  }, {
    key: 'toggleMenu',
    value: function toggleMenu() {
      this.setState({ menuOpen: !this.state.menuOpen });
      document.body.classList.toggle('g-noscroll');
    }
  }, {
    key: 'enterMobileSubnav',
    value: function enterMobileSubnav(e) {
      if (window.matchMedia('(max-width: 1000px)').matches) {
        var submenu = e.currentTarget.nextElementSibling;
        submenu.classList.add('active');
      }
    }
  }, {
    key: 'exitMobileSubnav',
    value: function exitMobileSubnav() {
      var submenus = document.querySelectorAll('nav .submenu.active');
      for (var i = 0; i < submenus.length; i++) {
        submenus[i].classList.remove('active');
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var data = reshapePreactComponents.decode(this.props._data);
      var menuOpen = this.state.menuOpen;

      return preact.h(
        'nav',
        { 'class': 'g-mega-nav', 'data-state': this.props._state },
        preact.h(
          'div',
          { 'class': 'g-container' },
          preact.h(NavBar, {
            data: data,
            toggle: this.toggleMenu,
            open: menuOpen,
            title: this.props.title,
            title_url: this.props.title_url,
            home_url: this.props.home_url
          }),
          preact.h('div', { 'class': menuOpen ? 'overlay active' : 'overlay' }),
          preact.h(NavMenu, {
            open: menuOpen,
            data: data,
            toggle: this.toggleMenu,
            enter: this.enterMobileSubnav,
            exit: this.exitMobileSubnav,
            title: this.props.title,
            home_url: this.props.home_url,
            title_url: this.props.title_url
          })
        )
      );
    }
  }]);

  return MegaNav;
}(preact.Component);

module.exports = MegaNav;
