import { h, Component } from 'preact'
import { decode } from 'reshape-preact-components'

import NavMenu from './NavMenu'
import NavBar from './NavBar'

export default class MegaNav extends Component {
  constructor(props) {
    super(props)
    this.state = { menuOpen: false }
    this.toggleMenu = this.toggleMenu.bind(this)
    this.handleEscKey = this.handleEscKey.bind(this)
    this.enterMobileSubnav = this.enterMobileSubnav.bind(this)
    this.exitMobileSubnav = this.exitMobileSubnav.bind(this)
  }

  componentDidMount() {
    window.addEventListener('keyup', this.handleEscKey)
  }

  handleEscKey(e) {
    if (e.keyCode === 27 && this.state.menuOpen) {
      this.toggleMenu()
    }
  }

  toggleMenu() {
    this.setState({ menuOpen: !this.state.menuOpen })
    document.body.classList.toggle('g-noscroll')
  }

  enterMobileSubnav(e) {
    if (window.matchMedia('(max-width: 1000px)').matches) {
      const submenu = e.currentTarget.nextElementSibling
      submenu.classList.add('active')
    }
  }

  exitMobileSubnav() {
    const submenus = document.querySelectorAll('nav .submenu.active')
    for (let i = 0; i < submenus.length; i++) {
      submenus[i].classList.remove('active')
    }
  }

  render() {
    const data = decode(this.props._data)
    const { menuOpen } = this.state
    return (
      <nav class="g-mega-nav" data-state={this.props._state}>
        <div class="g-container">
          <NavBar
            data={data}
            toggle={this.toggleMenu}
            open={menuOpen}
            title={this.props.title}
            title_url={this.props.title_url}
            home_url={this.props.home_url}
          />
          <div class={menuOpen ? 'overlay active' : 'overlay'} />
          <NavMenu
            open={menuOpen}
            data={data}
            toggle={this.toggleMenu}
            enter={this.enterMobileSubnav}
            exit={this.exitMobileSubnav}
            title={this.props.title}
            home_url={this.props.home_url}
            title_url={this.props.title_url}
          />
        </div>
      </nav>
    )
  }
}
